%% phi2 for deterministic switching, Rozenbaum JETP Lett. 2009, and personal communication 2017
% Ofer Kedem, Northwestern University 2017
% Contact at www.oferkedem.com
% Kedem, Lau and Weiss, Nano Lett., 2017

function phi2_det = phi2_det(xi,delta,n_elements)

% Phi1
A = zeros(length(xi),length(delta),length(n_elements));
C = zeros(length(xi),length(delta));

for i = 1:length(xi)
    for j = 1:length(delta)
        for k = 1:n_elements
            x = 2*pi*xi(i);
            y = 2*pi*delta(j);
            n = k;
            A(i,j,k) = (x*(7+2*x^2*n^2)*(1-cos(y*n)))/((1+x^2*n^2)^2*(16+x^2*n^2));
            C(i,j) = C(i,j) + A(i,j,k);
        end
    end
end

% Phi2
nD = -n_elements:1:n_elements;
mD = -n_elements:1:n_elements;
B = zeros(length(xi),length(delta),length(nD),length(mD));
D = zeros(length(xi),length(delta));

for i = 1:length(xi)
    for j = 1:length(delta)
        for k = 1:length(nD)
            for l = 1:length(mD)
                x = 2*pi*xi(i);
                y = 2*pi*delta(j);
                n = nD(k);
                m = mD(l);
                num1 = x*(5*n+(n+m)*(4-x^2*n^2));
                num2 = sin(y*n)*(1-cos(y*m))+sin(y*m)*(1-cos(y*n));
                denom = (n+m)*m*(1+x^2*n^2)*(16+x^2*n^2)*(1+x^2*(n+m)^2);
                B(i,j,k,l) = num1*num2/denom;
            end
        end
    end
end

for i = 1:length(xi)
    for j = 1:length(delta)
        x = 2*pi*xi(i);
        y = 2*pi*delta(j);
        D_left = 0;
        for k = n_elements+3:length(nD)
            n = nD(k);
            for l = (-nD(k)+2+n_elements):n_elements
                D_left = D_left + B(i,j,k,l) + B(i,j,l,k);  
            end
        end
        D_right = 0;
        for k = n_elements+2:length(nD)
            for l = n_elements+2:length(mD)
                D_right = D_right + B(i,j,k,l);                
            end
        end
        D(i,j) = D_left + D_right;
        G(i,j) = (1-2*delta(j))*C(i,j)-(1/(2*pi))*D(i,j);
        phi2_det(i,j) = (12/(pi^2))*x*G(i,j);
    end
end
end